@@ -1,4 +1,4 @@
-## Some convenience names
+# Some convenience names
 
 #' @rdname detect_separation
 #' @export
@@ -8,5 +8,10 @@ detectSeparation <- detect_separation
 #' @export
 detectSeparationControl <- detect_separation_control
 
+#' @rdname check_infinite_estimates
 #' @export
 checkInfiniteEstimates <- check_infinite_estimates
+
+#' @rdname detect_infinite_estimates
+#' @export
+detectInfiniteEstimates <- detect_infinite_estimates
